# from .helpers import generate_spike_train, STTC_formula, STTC_single
# from .cpu_main import STTC, null, add_dt, shift_signal

# try:
#     import torch
#     from .gpu_main import STTC_gpu, null_gpu, add_dt_gpu, shift_signal_gpu
#     print("GPU functions available on PyTorch backend.")
# except ImportError:
#     STTC_gpu = None
#     null_gpu = None
#     add_dt_gpu = None
#     shift_signal_gpu = None
#     print("PyTorch not found. GPU functions are unavailable.")


################

import os
from .helpers import generate_spike_train, spike_times_to_train
from .numpy_main import STTC as STTC_CPU

try:
    import torch
    from .torch_main import STTC as STTC_GPU
    TORCH_AVAILABLE = True
except ImportError:
    TORCH_AVAILABLE = False
    
    
def get_default_backend():
    """Determine the default backend based on environment and availability."""
    backend = os.getenv("STTC_BACKEND", "").lower()

    if backend == "numpy":
        return STTC_CPU
    elif backend == "torch":
        if TORCH_AVAILABLE:
            return STTC_GPU
        raise ImportError("Torch is not installed, but 'torch' backend was requested.")
    return STTC_GPU if TORCH_AVAILABLE else STTC_CPU


# Set the initial backend
STTC = get_default_backend()

def set_backend(backend: str):
    """
    Set the backend explicitly.

    Parameters:
    backend (str): 'numpy' or 'torch'
    """
    global STTC
    backend = backend.lower()

    if backend == "numpy":
        STTC = STTC_CPU
    elif backend == "torch":
        if TORCH_AVAILABLE:
            STTC = STTC_GPU
        else:
            raise ImportError("Torch is not installed, cannot switch to GPU backend.")
    else:
        raise ValueError("Invalid backend. Choose 'numpy' or 'torch'.")

